@@ -3,7 +3,6 @@
  */
 package org.gcube.portlets.user.gcubegisviewer.server;
 
-import static org.gcube.common.authorization.client.Constants.authorizationService;
 import static org.gcube.resources.discovery.icclient.ICFactory.client;
 import static org.gcube.resources.discovery.icclient.ICFactory.clientFor;
 import static org.gcube.resources.discovery.icclient.ICFactory.queryFor;
@@ -34,7 +33,6 @@ import org.apache.log4j.Logger;
 import org.gcube.application.framework.core.session.ASLSession;
 import org.gcube.application.framework.core.session.SessionManager;
 import org.gcube.common.encryption.StringEncrypter;
-import org.gcube.common.geoserverinterface.GeoCaller;
 import org.gcube.common.homelibrary.home.HomeLibrary;
 import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
 import org.gcube.common.homelibrary.home.workspace.Workspace;
@@ -183,7 +181,7 @@ public class GCubeGisViewerServletImpl extends GisViewerServiceImpl implements G
 		parameters.setUser(ap.username()); //username
 
 		String decryptedPassword = StringEncrypter.getEncrypter().decrypt(ap.password());
-		logger.info("resourceName: "+resourceName +", scope: "+scope.toString() +", username: "+ap.username() +", password: "+ap.password() +" decryptedPassword: "+decryptedPassword);
+		logger.info("resourceName: "+resourceName +", scope: "+scope.toString() +", username: "+ap.username() +", password: XXXXX");
 		parameters.setPassword(decryptedPassword); //password
 
 		return parameters;
@@ -356,33 +354,33 @@ public class GCubeGisViewerServletImpl extends GisViewerServiceImpl implements G
 	/* (non-Javadoc)
 	 * @see org.gcube.portlets.user.gisviewer.server.GisViewerServiceImpl#getGeoCaller()
 	 */
-	@Override
-	protected GeoCaller getGeoCaller() throws Exception
-	{
-		HttpSession httpSession = this.getThreadLocalRequest().getSession();
-		ASLSession session = getASLSession(httpSession);
-		GeoCaller geoCaller = (GeoCaller) session.getAttribute(GEOCALLER_ATTRIBUTE_NAME);
-		if (geoCaller==null) {
-			try {
-
-				GisViewerServiceParameters parameters = getParameters();
-				String geoserverUrl = parameters.getGeoServerUrl();
-				String geonetworkUrl = parameters.getGeoNetworkUrl();
-				String gnUser = parameters.getGeoNetworkUser();
-				String gnPwd = parameters.getGeoNetworkPwd();
-				String gsUser = parameters.getGeoServerUser();
-				String gsPwd = parameters.getGeoServerPwd();
-
-				geoCaller = new GeoCaller(geonetworkUrl, gnUser, gnPwd, geoserverUrl, gsUser, gsPwd, researchMethod);
-				session.setAttribute(GEOCALLER_ATTRIBUTE_NAME, geoCaller);
-
-			} catch (Exception e) {
-				throw new Exception("Error initializing the GeoCaller", e);
-			}
-		}
-
-		return geoCaller;
-	}
+//	@Override
+//	protected GeoCaller getGeoCaller() throws Exception
+//	{
+//		HttpSession httpSession = this.getThreadLocalRequest().getSession();
+//		ASLSession session = getASLSession(httpSession);
+//		GeoCaller geoCaller = (GeoCaller) session.getAttribute(GEOCALLER_ATTRIBUTE_NAME);
+//		if (geoCaller==null) {
+//			try {
+//
+//				GisViewerServiceParameters parameters = getParameters();
+//				String geoserverUrl = parameters.getGeoServerUrl();
+//				String geonetworkUrl = parameters.getGeoNetworkUrl();
+//				String gnUser = parameters.getGeoNetworkUser();
+//				String gnPwd = parameters.getGeoNetworkPwd();
+//				String gsUser = parameters.getGeoServerUser();
+//				String gsPwd = parameters.getGeoServerPwd();
+//
+//				geoCaller = new GeoCaller(geonetworkUrl, gnUser, gnPwd, geoserverUrl, gsUser, gsPwd, researchMethod);
+//				session.setAttribute(GEOCALLER_ATTRIBUTE_NAME, geoCaller);
+//
+//			} catch (Exception e) {
+//				throw new Exception("Error initializing the GeoCaller", e);
+//			}
+//		}
+//
+//		return geoCaller;
+//	}
 
 
 	/**
@@ -487,8 +485,8 @@ public class GCubeGisViewerServletImpl extends GisViewerServiceImpl implements G
 		logger.debug("Get security token return: "+session.getSecurityToken());
 
 		if(session.getSecurityToken()==null || session.getSecurityToken().isEmpty()){
-			logger.warn("Security token retured from ASL is null or empty, I'm setting security token...");
-			setAuthorizationToken(session);
+			logger.error("Security token retured from ASL is null or empty!!!");
+			return null;
 		}
 
 		return session.getSecurityToken();
@@ -500,7 +498,7 @@ public class GCubeGisViewerServletImpl extends GisViewerServiceImpl implements G
 	 *
 	 * @param session the new authorization token
 	 */
-	private static void setAuthorizationToken(ASLSession session) {
+	/*private static void setAuthorizationToken(ASLSession session) {
 		String username = session.getUsername();
 		String scope = session.getScope();
 		ScopeProvider.instance.set(scope);
@@ -512,7 +510,7 @@ public class GCubeGisViewerServletImpl extends GisViewerServiceImpl implements G
 		logger.debug("received token: "+token);
 		session.setSecurityToken(token);
 		logger.info("Security token set in session for: "+username + " on " + scope);
-	}
+	}*/
 
 
 	/* (non-Javadoc)
